"""Repository layer for campaign persistence.

Re-exports all repository classes for convenient access.
"""

from unfamiliar.db.repositories.campaign import CampaignRepository
from unfamiliar.db.repositories.chain import ChainRepository
from unfamiliar.db.repositories.file_snapshot import FileSnapshotRepository
from unfamiliar.db.repositories.mission import MissionRepository
from unfamiliar.db.repositories.mission_file_ref import MissionFileRefRepository
from unfamiliar.db.repositories.mission_link import MissionLinkRepository
from unfamiliar.db.repositories.module import ModuleRepository

__all__ = [
    "CampaignRepository",
    "ChainRepository",
    "FileSnapshotRepository",
    "MissionRepository",
    "MissionFileRefRepository",
    "MissionLinkRepository",
    "ModuleRepository",
]
