"""LLM provider abstraction via LangChain.

Provides a factory for creating chat models from different providers
based on user configuration. Supports Anthropic and GLM (Zhipu).
"""

from unfamiliar.llm.providers.factory import create_chat_model

__all__ = ["create_chat_model"]
