"""Security analysis — secret detection and dependency CVE scanning."""

from unfamiliar.analysis.security.secrets import scan_for_secrets
from unfamiliar.analysis.security.vulnerabilities import scan_vulnerabilities

__all__ = ["scan_for_secrets", "scan_vulnerabilities"]
