"""Textual TUI application — persistent interactive session for investigations.

This package provides the interactive TUI for the Unfamiliar investigation tool.
"""

from unfamiliar.tui.app import UnfamiliarApp, run_tui

__all__ = [
    "UnfamiliarApp",
    "run_tui",
]
